=======================
Scenario Tool Interface
=======================


Python interface to the scenario-tool https://www.wsc-scenario.org.au



Description
===========

The Scenario Tool Interface provides an easy to use Python interface to the Scenario-Tool's REST api.
It provides power users with the ability to create project, create complex workflows and run sensitivity
and uncertainty analysis. Combined with powerful python notebook's and data analysis tools
such as pandas if provides a powerful tool to gain insights for complex integrated urban water management strategies.


The API is in its early development stages and feedback on its usability and improvements to the functionality and
very welcome.


Install
=======


pip install scenario-tool-interface


Documentation
=============

https://scenario-tool-interface.readthedocs.io

